This directory is used for testing MyPy type-checking against stub files
generated by bravado-types.  The tests will generate a petstore module based on
the schema.json file, and then invoke MyPy for the modules in this directory.
The modules are annotated with comments indicating the expected MyPy output,
which are parsed and verified by the tests.
